@@ -26,6 +26,12 @@
 #endif /* !PLUGIN_NAME */
 
 static MANAGER *manager = NULL;
+static int timeout = -1;
+
+static GOptionEntry entries[] = {
+        { "exit-time", 0, 0, G_OPTION_ARG_INT, &timeout, "Exit after n seconds time", NULL },
+        {NULL}
+};
 
 static gboolean
 has_settings (void)
@@ -41,6 +47,15 @@ has_settings (void)
 	return FALSE;
 }
 
+static void
+print_enable_disable_help (void)
+{
+	fprintf (stderr, "To deactivate:\n");
+	fprintf (stderr, "\tgsettings set org.gnome.settings-daemon.plugins." SCHEMA_NAME " active false\n");
+	fprintf (stderr, "To reactivate:\n");
+	fprintf (stderr, "\tgsettings set org.gnome.settings-daemon.plugins." SCHEMA_NAME " active true\n");
+}
+
 int
 main (int argc, char **argv)
 {
@@ -55,25 +70,25 @@ main (int argc, char **argv)
 	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
         error = NULL;
-        if (! gtk_init_with_args (&argc, &argv, NULL, NULL, NULL, &error)) {
+        if (! gtk_init_with_args (&argc, &argv, SCHEMA_NAME, entries, NULL, &error)) {
                 fprintf (stderr, "%s\n", error->message);
                 g_error_free (error);
                 exit (1);
         }
 
-	if (has_settings () == FALSE) {
-		fprintf (stderr, "The schemas for plugin '%s' aren't available, check your installation.\n", SCHEMA_NAME);
-		exit (1);
-	}
+	if (timeout > 0)
+		g_timeout_add_seconds (timeout, (GSourceFunc) gtk_main_quit, NULL);
 
-        settings = g_settings_new ("org.gnome.settings-daemon.plugins." SCHEMA_NAME);
-        if (g_settings_get_boolean (settings, "active") != FALSE) {
-		fprintf (stderr, "Plugin '%s' is not disabled. You need to disable it before launching the test application.\n", SCHEMA_NAME);
-		fprintf (stderr, "To deactivate:\n");
-		fprintf (stderr, "\tgsettings set org.gnome.settings-daemon.plugins." SCHEMA_NAME " active false\n");
-		fprintf (stderr, "To reactivate:\n");
-		fprintf (stderr, "\tgsettings set org.gnome.settings-daemon.plugins." SCHEMA_NAME " active true\n");
-		exit (1);
+	if (has_settings () == FALSE) {
+		fprintf (stderr, "The schemas for plugin '%s' isn't available, check your installation.\n", SCHEMA_NAME);
+	} else {
+		settings = g_settings_new ("org.gnome.settings-daemon.plugins." SCHEMA_NAME);
+		if (g_settings_get_boolean (settings, "active") != FALSE) {
+			fprintf (stderr, "Plugin '%s' is not disabled. You need to disable it before launching the test application.\n", SCHEMA_NAME);
+			print_enable_disable_help ();
+			exit (1);
+		}
+		print_enable_disable_help();
 	}
 
         manager = NEW ();
