@@ -33,8 +33,10 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
+#include <gdk/gdkx.h>
+#include <X11/Xatom.h>
 
-#include "gnome-settings-session.h"
+#include "gnome-settings-bus.h"
 #include "gnome-settings-profile.h"
 #include "gsd-remote-display-manager.h"
 
@@ -141,6 +143,49 @@ vino_vanished_cb (GDBusConnection         *connection,
 		g_clear_object (&manager->priv->cancellable);
 	}
 	g_clear_object (&manager->priv->vino_proxy);
+
+	/* And reset for us to have animations */
+	g_settings_set_boolean (manager->priv->desktop_settings,
+				"enable-animations",
+				TRUE);
+}
+
+static gboolean
+gsd_display_has_extension (const gchar *ext)
+{
+	int op, event, error;
+
+	return XQueryExtension (gdk_x11_get_default_xdisplay (),
+				ext, &op, &event, &error);
+}
+
+static gboolean
+gsd_display_has_llvmpipe (void)
+{
+        glong is_software_rendering_atom;
+        Atom type;
+        gint format;
+        gulong nitems;
+        gulong bytes_after;
+        guchar *data;
+        GdkDisplay *display;
+
+        display = gdk_display_get_default ();
+        is_software_rendering_atom = gdk_x11_get_xatom_by_name_for_display (display, "_GNOME_IS_SOFTWARE_RENDERING");
+        gdk_x11_display_error_trap_push (display);
+        XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display),  gdk_x11_get_default_root_xwindow (),
+                            is_software_rendering_atom,
+                            0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+                            &bytes_after, &data);
+        gdk_x11_display_error_trap_pop_ignored (display);
+
+        if (type == XA_CARDINAL) {
+               glong *is_accelerated_ptr = (glong*) data;
+
+               return (*is_accelerated_ptr == 1);
+        }
+
+        return FALSE;
 }
 
 gboolean
@@ -164,6 +209,24 @@ gsd_remote_display_manager_start (GsdRemoteDisplayManager *manager,
 		goto out;
 	}
 
+	/* Xvnc exposes an extension named VNC-EXTENSION */
+	if (gsd_display_has_extension ("VNC-EXTENSION")) {
+		g_debug ("Disabling animations because VNC-EXTENSION was detected");
+		g_settings_set_boolean (manager->priv->desktop_settings,
+					"enable-animations",
+					FALSE);
+		goto out;
+	}
+
+	/* disable animations if running under llvmpipe */
+	if (gsd_display_has_llvmpipe ()) {
+		g_debug ("Disabling animations because llvmpipe was detected");
+		g_settings_set_boolean (manager->priv->desktop_settings,
+					"enable-animations",
+					FALSE);
+		goto out;
+	}
+
 	/* Monitor Vino's usage */
 	manager->priv->vino_watch_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
 							 "org.gnome.Vino",
