@@ -57,7 +57,6 @@
 
 #define KEY_ROTATION            "rotation"
 #define KEY_TOUCH               "touch"
-#define KEY_TPCBUTTON           "tablet-pc-button"
 #define KEY_IS_ABSOLUTE         "is-absolute"
 #define KEY_AREA                "area"
 #define KEY_DISPLAY             "display"
@@ -326,8 +325,43 @@ set_area (GsdWacomDevice  *device,
                 return;
         }
 
-        wacom_set_property (device, &property);
-        g_variant_unref (value);
+        if (property.data.i[0] == -1 &&
+            property.data.i[1] == -1 &&
+            property.data.i[2] == -1 &&
+            property.data.i[3] == -1) {
+                gint *area;
+                area = gsd_wacom_device_get_default_area (device);
+                property.data.i = area;
+                g_debug ("Resetting area to: %d, %d, %d, %d",
+                         property.data.i[0],
+                         property.data.i[1],
+                         property.data.i[2],
+                         property.data.i[3]);
+                wacom_set_property (device, &property);
+                g_free (area);
+        } else {
+                g_debug ("Setting area to: %d, %d, %d, %d",
+                         property.data.i[0],
+                         property.data.i[1],
+                         property.data.i[2],
+                         property.data.i[3]);
+                wacom_set_property (device, &property);
+        }
+}
+
+static void
+reset_area (GsdWacomDevice *device)
+{
+        GVariant *values[4], *variant;
+        guint i;
+
+        /* Set area to default values for the device */
+        for (i = 0; i < G_N_ELEMENTS (values); i++)
+                values[i] = g_variant_new_int32 (-1);
+        variant = g_variant_new_array (G_VARIANT_TYPE_INT32, values, G_N_ELEMENTS (values));
+
+        set_area (device, variant);
+        g_variant_unref (variant);
 }
 
 /* Returns the rotation to apply a device relative to the current rotation of the output */
@@ -484,15 +518,16 @@ set_keep_aspect (GsdWacomDevice *device,
 	variant = g_variant_new_array (G_VARIANT_TYPE_INT32, values, G_N_ELEMENTS (values));
 
         /* If keep_aspect is not set, just reset the area to default and let
-         * gsettings notification call set_area() for us...
+         * gsettings notification call reset_area() for us...
          */
 	if (!keep_aspect) {
 		g_settings_set_value (settings, KEY_AREA, variant);
+		g_variant_unref (variant);
 		return;
         }
 
         /* Reset the device area to get the default area */
-	set_area (device, variant);
+	reset_area (device);
 
 	/* Get current rotation */
 	rotation = g_settings_get_enum (settings, KEY_ROTATION);
@@ -575,26 +610,6 @@ set_touch (GsdWacomDevice *device,
         wacom_set_property (device, &property);
 }
 
-static void
-set_tpcbutton (GsdWacomDevice *device,
-	       gboolean        tpcbutton)
-{
-        /* Wacom's TPCButton option which this setting emulates is to enable
-         * Tablet PC stylus behaviour when on. The property "Hover Click"
-         * works the other way round, i.e. if Hover Click is enabled this
-         * is the equivalent of TPC behaviour disabled. */
-        gchar data = tpcbutton ? 0 : 1;
-        PropertyHelper property = {
-                .name = "Wacom Hover Click",
-                .nitems = 1,
-                .format = 8,
-                .type   = XA_INTEGER,
-                .data.c = &data,
-        };
-
-        wacom_set_property (device, &property);
-}
-
 static void
 set_pressurethreshold (GsdWacomDevice *device,
                        gint            threshold)
@@ -840,16 +855,8 @@ set_wacom_settings (GsdWacomManager *manager,
 	}
 
 	if (type == WACOM_TYPE_CURSOR) {
-		GVariant *values[4], *variant;
-		guint i;
-
 		set_absolute (device, FALSE);
-
-		for (i = 0; i < G_N_ELEMENTS (values); i++)
-			values[i] = g_variant_new_int32 (-1);
-
-		variant = g_variant_new_array (G_VARIANT_TYPE_INT32, values, G_N_ELEMENTS (values));
-		set_area (device, variant);
+		reset_area (device);
 		return;
 	}
 
@@ -874,9 +881,6 @@ set_wacom_settings (GsdWacomManager *manager,
 		return;
 	}
 
-	if (type == WACOM_TYPE_STYLUS)
-		set_tpcbutton (device, g_settings_get_boolean (settings, KEY_TPCBUTTON));
-
 	set_absolute (device, g_settings_get_boolean (settings, KEY_IS_ABSOLUTE));
 
 	/* Ignore touch devices as they do not share the same range of values for area */
@@ -909,8 +913,6 @@ wacom_settings_changed (GSettings      *settings,
 	} else if (g_str_equal (key, KEY_TOUCH)) {
 	        if (type == WACOM_TYPE_TOUCH)
 			set_touch (device, g_settings_get_boolean (settings, key));
-	} else if (g_str_equal (key, KEY_TPCBUTTON)) {
-		set_tpcbutton (device, g_settings_get_boolean (settings, key));
 	} else if (g_str_equal (key, KEY_IS_ABSOLUTE)) {
 		if (type != WACOM_TYPE_CURSOR &&
 		    type != WACOM_TYPE_PAD &&
